
#
# REASON:
#
# When a pod only have vendored library, and the 'use_modular_header' is on, cocoapods won't
# generate a modulemap (so module is not working), because it consider it as "should_build? == false".
#
# It's a bug of cocoapods.
#
# We fix it by changing the `install!` method:
#
#    when a pod is (target.should_build? == true && target.define_module?),
#    we treat it differently: like normal pods,
#       - create_umbrella_header
#       - create_module_map
#

require_relative 'patch_common'

module Pod
  class Installer
    class Xcode
      class PodsProjectGenerator
        class PodTargetInstaller


          FIX_MODULE_OLD_install = instance_method(:install!)
          define_method(:install!) do

              if (not target.should_build?) && target.should_generate_module_map_for_a_pod_should_not_build?
                  # special handling for pod with no source code

                  # Most code below are copied from original install! method
                  # Manually checked the 1.6.0/ 1.6.1, they are all the same. So it's safe.
                  native_target = add_target
                  _, file_accessors = target.file_accessors.partition { |fa| fa.spec.test_specification? }
                  resource_bundle_targets = add_resources_bundle_targets(file_accessors).values.flatten
                  create_xcconfig_file(native_target, resource_bundle_targets)

                  if target.defines_module?
                    create_module_map(native_target) do |generator|
                      generator.headers.concat module_map_additional_headers
                    end
                    create_umbrella_header(native_target) do |generator|
                      generator.imports += file_accessors.flat_map do |file_accessor|
                        header_dir = if !target.requires_frameworks? && dir = file_accessor.spec_consumer.header_dir
                                       Pathname.new(dir)
                                     end

                        file_accessor.public_headers.map do |public_header|
                          public_header = if header_mappings_dir
                                            public_header.relative_path_from(header_mappings_dir)
                                          else
                                            public_header.basename
                                          end
                          if header_dir
                            public_header = header_dir.join(public_header)
                          end
                          public_header
                        end
                      end
                    end
                  end

                  if target.requires_frameworks?
                    unless skip_info_plist?(native_target)
                      create_info_plist_file(target.info_plist_path, native_target, target.version, target.platform)
                    end
                    create_build_phase_to_symlink_header_folders(native_target)
                  elsif target.uses_swift?
                    add_swift_static_library_compatibility_header_phase(native_target)
                  end


                  clean_support_files_temp_dir
                  TargetInstallationResult.new(target, native_target, resource_bundle_targets)


              else
                  # call original
                  FIX_MODULE_OLD_install.bind(self).()
              end

          end # patch ended

        end
      end
    end
  end
end




